==> foundation-2.6.1.tgz: package/Rss/Rss.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const Rss = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M26.258 64.949a8.78 8.78 0 00-8.78 8.784 8.782 8.782 0 1017.564 0 8.78 8.78 0 00-8.784-8.784z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M23.536 40.801c-.046 0-.09.006-.135.007v-.007h-3.464v.039a3.437 3.437 0 00-3.056 3.344h-.007v6.159h.041a3.43 3.43 0 003.021 3.002v.039H23.4v-.048c.045.001.09.007.135.007 12.772 0 23.173 10.321 23.311 23.061h-.033v3.464h.039a3.437 3.437 0 003.344 3.056v.007h6.158v-.041a3.43 3.43 0 003.002-3.021h.039v-3.464h-.006c-.137-19.657-16.166-35.604-35.853-35.604z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M83.119 76.403C82.98 43.664 56.308 17.07 23.536 17.07c-.046 0-.09.006-.135.007v-.007h-3.464v.039a3.437 3.437 0 00-3.056 3.344h-.007v6.159h.041a3.429 3.429 0 003.021 3.002v.039H23.4v-.048c.045.001.09.007.135.007 25.857 0 46.902 20.967 47.041 46.792h-.035v3.464h.039a3.437 3.437 0 003.344 3.056v.007h6.159v-.041a3.43 3.43 0 003.002-3.021h.039v-3.464h-.005z"
  }));
});
Rss.displayName = 'Rss';
export const RssDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/Rss/Rss.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var Rss = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M26.258 64.949a8.78 8.78 0 00-8.78 8.784 8.782 8.782 0 1017.564 0 8.78 8.78 0 00-8.784-8.784z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M23.536 40.801c-.046 0-.09.006-.135.007v-.007h-3.464v.039a3.437 3.437 0 00-3.056 3.344h-.007v6.159h.041a3.43 3.43 0 003.021 3.002v.039H23.4v-.048c.045.001.09.007.135.007 12.772 0 23.173 10.321 23.311 23.061h-.033v3.464h.039a3.437 3.437 0 003.344 3.056v.007h6.158v-.041a3.43 3.43 0 003.002-3.021h.039v-3.464h-.006c-.137-19.657-16.166-35.604-35.853-35.604z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M83.119 76.403C82.98 43.664 56.308 17.07 23.536 17.07c-.046 0-.09.006-.135.007v-.007h-3.464v.039a3.437 3.437 0 00-3.056 3.344h-.007v6.159h.041a3.429 3.429 0 003.021 3.002v.039H23.4v-.048c.045.001.09.007.135.007 25.857 0 46.902 20.967 47.041 46.792h-.035v3.464h.039a3.437 3.437 0 003.344 3.056v.007h6.159v-.041a3.43 3.43 0 003.002-3.021h.039v-3.464h-.005z"
  }));
});
Rss.displayName = 'Rss';
export var RssDimensions = {
  height: 100,
  width: 100
};
